# Test Coverage Report

Generated: Fri 2013-09-20 15:24 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 227 | 197 | 29 | 99.5%
frequently.__init__ | 1 | 1 | 0 | 100.0%
frequently.forms | 38 | 31 | 7 | 100.0%
frequently.models | 47 | 36 | 10 | 97.3%
frequently.templatetags.frequently_tags | 10 | 8 | 2 | 100.0%
frequently.views | 131 | 121 | 10 | 100.0%

Excluded packages and modules
Error packages and modules